@@ -1,34 +1,37 @@
-# @(#)$Ident: Exception.pm 2013-05-08 06:57 pjf ;
+# @(#)$Ident: Exception.pm 2013-05-08 20:57 pjf ;
 
 package IPC::SRLock::Exception;
 
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 8 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.11.%d', q$Rev: 9 $ =~ /\d+/gmx );
 
 use Moose;
 use MooseX::Types::Moose qw(Str);
 
-extends q(File::DataClass::Exception);
-
-File::DataClass::Exception->add_roles( 'ErrorLeader' );
+extends q(Unexpected);
+with    q(Unexpected::TraitFor::ErrorLeader);
 
 has '+class' => default => __PACKAGE__;
 
 has 'out'    => is => 'ro', isa => Str, default => q();
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
 
 =pod
 
+=encoding utf8
+
 =head1 Name
 
 IPC::SRLock::Exception - Exception class
 
 =head1 Version
 
-This documents version v0.11.$Rev: 8 $
+This documents version v0.11.$Rev: 9 $
 
 =head1 Synopsis
 
@@ -38,11 +41,23 @@ This documents version v0.11.$Rev: 8 $
 
 =head1 Description
 
-Implements throw and catch error semantics. Inherits from
-L<File::DataClass::Exception>
+Implements throw and catch error semantics. Inherits from L<Unexpected>
 
 =head1 Configuration and Environment
 
+Overrides the C<class> attribute setting it's value to this class
+
+Defines these attributes;
+
+=over 3
+
+=item C<out>
+
+A string containing the output from whatever was being called before
+it threw
+
+=back
+
 =head1 Subroutines/Methods
 
 =head2 as_string
@@ -91,7 +106,11 @@ None
 
 =over 3
 
-=item L<File::DataClass::Exception>
+=item L<Moose>
+
+=item L<Moose::Types::Moose>
+
+=item L<Unexpected>
 
 =back
 
